@@ -55,13 +55,17 @@ void AbstractFileListener::setDatabaseInterface(DatabaseInterface *model)
         connect(this, &AbstractFileListener::newTrackFile, d->mFileListing, &AbstractFileListing::newTrackFile);
         connect(d->mFileListing, &AbstractFileListing::tracksList, model, &DatabaseInterface::insertTracksList);
         connect(d->mFileListing, &AbstractFileListing::removedTracksList, model, &DatabaseInterface::removeTracksList);
-        connect(d->mFileListing, &AbstractFileListing::modifyTracksList, model, &DatabaseInterface::modifyTracksList);
+        connect(d->mFileListing, &AbstractFileListing::modifyTracksList, model, &DatabaseInterface::insertTracksList);
         connect(d->mFileListing, &AbstractFileListing::askRestoredTracks,
                 model, &DatabaseInterface::askRestoredTracks);
         connect(model, &DatabaseInterface::restoredTracks,
                 d->mFileListing, &AbstractFileListing::restoredTracks);
-
-        QMetaObject::invokeMethod(d->mFileListing, "init", Qt::QueuedConnection);
+        connect(model, &DatabaseInterface::cleanedDatabase,
+                d->mFileListing, &AbstractFileListing::refreshContent);
+        connect(model, &DatabaseInterface::finishRemovingTracksList,
+                d->mFileListing, &AbstractFileListing::databaseFinishedRemovingTracksList);
+        connect(model, &DatabaseInterface::finishInsertingTracksList,
+                d->mFileListing, &AbstractFileListing::databaseFinishedInsertingTracksList);
     }
 
     Q_EMIT databaseInterfaceChanged();
@@ -79,7 +83,12 @@ void AbstractFileListener::quitListener()
 {
     applicationAboutToQuit();
 
-    Q_EMIT clearDatabase(d->mFileListing->sourceName());
+    Q_EMIT clearDatabase();
+}
+
+void AbstractFileListener::setAllRootPaths(const QStringList &allRootPaths)
+{
+    d->mFileListing->setAllRootPaths(allRootPaths);
 }
 
 void AbstractFileListener::setFileListing(AbstractFileListing *fileIndexer)
