@@ -61,7 +61,7 @@ Q_SIGNALS:
 
     void configurationChanged();
 
-    void clearDatabase(const QString &listenerName);
+    void clearDatabase();
 
     void newNotification(NotificationItem notification);
 
@@ -75,6 +75,8 @@ public Q_SLOTS:
 
     void quitListener();
 
+    void setAllRootPaths(const QStringList &allRootPaths);
+
 protected:
 
     void setFileListing(AbstractFileListing *fileIndexer);
