@@ -20,6 +20,7 @@
 #include "musiclistenersmanager.h"
 #include "elisaimportapplication.h"
 #include "elisa_settings.h"
+#include "musicaudiotrack.h"
 
 #include <QCoreApplication>
 #include <QCommandLineParser>
@@ -35,8 +36,6 @@ int main(int argc, char *argv[])
     qRegisterMetaType<QList<MusicAudioTrack>>("QVector<MusicAudioTrack>");
     qRegisterMetaType<QVector<qulonglong>>("QVector<qulonglong>");
     qRegisterMetaType<QHash<qulonglong,int>>("QHash<qulonglong,int>");
-    qRegisterMetaType<MusicAlbum>("MusicAlbum");
-    qRegisterMetaType<MusicArtist>("MusicArtist");
     qRegisterMetaType<QMap<QString, int>>();
     qRegisterMetaType<NotificationItem>("NotificationItem");
     qRegisterMetaType<QMap<QString,int>>("QMap<QString,int>");
@@ -55,7 +54,7 @@ int main(int argc, char *argv[])
     MusicListenersManager myMusicManager;
     ElisaImportApplication myApplication;
 
-    QObject::connect(&myMusicManager, &MusicListenersManager::indexingRunningChanged,
+    QObject::connect(&myMusicManager, &MusicListenersManager::indexerBusyChanged,
             &myApplication, &ElisaImportApplication::indexingChanged);
 
     return app.exec();
