@@ -18,6 +18,8 @@
 #ifndef FILESCANNER_H
 #define FILESCANNER_H
 
+#include "elisaLib_export.h"
+
 #include "musicaudiotrack.h"
 
 #include <QUrl>
@@ -26,12 +28,6 @@
 
 #include <memory>
 
-namespace KFileMetaData {
-
-class ExtractorCollection;
-
-}
-
 namespace Baloo {
 
 class File;
@@ -40,7 +36,7 @@ class File;
 
 class FileScannerPrivate;
 
-class FileScanner
+class ELISALIB_EXPORT FileScanner
 {
 public:
 
