@@ -56,22 +56,55 @@ void ManageHeaderBar::setAlbumRole(int value)
     Q_EMIT albumRoleChanged();
 }
 
+void ManageHeaderBar::setAlbumArtistRole(int value)
+{
+    mAlbumArtistRole = value;
+    Q_EMIT albumArtistRoleChanged();
+}
+
+void ManageHeaderBar::setFileNameRole(int value)
+{
+    mFileNameRole = value;
+    Q_EMIT fileNameRoleChanged();
+}
+
 int ManageHeaderBar::albumRole() const
 {
     return mAlbumRole;
 }
 
+int ManageHeaderBar::albumArtistRole() const
+{
+    return mAlbumArtistRole;
+}
+
+int ManageHeaderBar::fileNameRole() const
+{
+    return mFileNameRole;
+}
+
 void ManageHeaderBar::setImageRole(int value)
 {
     mImageRole = value;
     Q_EMIT imageRoleChanged();
 }
 
+void ManageHeaderBar::setDatabaseIdRole(int databaseIdRole)
+{
+    mDatabaseIdRole = databaseIdRole;
+    Q_EMIT databaseIdRoleChanged();
+}
+
 int ManageHeaderBar::imageRole() const
 {
     return mImageRole;
 }
 
+int ManageHeaderBar::databaseIdRole() const
+{
+    return mDatabaseIdRole;
+}
+
 void ManageHeaderBar::setAlbumIdRole(int albumIdRole)
 {
     mAlbumIdRole = albumIdRole;
@@ -92,6 +125,33 @@ QVariant ManageHeaderBar::album() const
     return mCurrentTrack.data(mAlbumRole);
 }
 
+QVariant ManageHeaderBar::albumArtist() const
+{
+    if (!mCurrentTrack.isValid()) {
+        return QString();
+    }
+
+    return mCurrentTrack.data(mAlbumArtistRole);
+}
+
+QString ManageHeaderBar::fileName() const
+{
+    QString result;
+
+    if (!mCurrentTrack.isValid()) {
+        return result;
+    }
+
+    auto fileNameUrl = mCurrentTrack.data(mFileNameRole).toUrl();
+    if (fileNameUrl.isLocalFile()) {
+        result = fileNameUrl.toLocalFile();
+    } else {
+        result = fileNameUrl.toString();
+    }
+
+    return result;
+}
+
 QVariant ManageHeaderBar::title() const
 {
     if (!mCurrentTrack.isValid()) {
@@ -119,6 +179,15 @@ QUrl ManageHeaderBar::image() const
     return mCurrentTrack.data(mImageRole).toUrl();
 }
 
+qulonglong ManageHeaderBar::databaseId() const
+{
+    if (!mCurrentTrack.isValid()) {
+        return 0;
+    }
+
+    return mCurrentTrack.data(mDatabaseIdRole).toULongLong();
+}
+
 qulonglong ManageHeaderBar::albumId() const
 {
     if (!mCurrentTrack.isValid()) {
@@ -200,7 +269,10 @@ void ManageHeaderBar::tracksDataChanged(const QModelIndex &topLeft, const QModel
         notifyArtistProperty();
         notifyTitleProperty();
         notifyAlbumProperty();
+        notifyAlbumArtistProperty();
+        notifyFileNameProperty();
         notifyImageProperty();
+        notifyDatabaseIdProperty();
         notifyAlbumIdProperty();
         notifyIsValidProperty();
     } else {
@@ -214,9 +286,18 @@ void ManageHeaderBar::tracksDataChanged(const QModelIndex &topLeft, const QModel
             if (oneRole == mAlbumRole) {
                 notifyAlbumProperty();
             }
+            if (oneRole == mAlbumArtistRole) {
+                notifyAlbumArtistProperty();
+            }
+            if (oneRole == mFileNameRole) {
+                notifyFileNameProperty();
+            }
             if (oneRole == mImageRole) {
                 notifyImageProperty();
             }
+            if (oneRole == mDatabaseIdRole) {
+                notifyDatabaseIdProperty();
+            }
             if (oneRole == mAlbumIdRole) {
                 notifyAlbumIdProperty();
             }
@@ -262,7 +343,10 @@ void ManageHeaderBar::tracksRemoved(const QModelIndex &parent, int first, int la
         notifyArtistProperty();
         notifyTitleProperty();
         notifyAlbumProperty();
+        notifyAlbumArtistProperty();
+        notifyFileNameProperty();
         notifyImageProperty();
+        notifyDatabaseIdProperty();
         notifyAlbumIdProperty();
         notifyIsValidProperty();
         notifyRemainingTracksProperty();
@@ -303,6 +387,26 @@ void ManageHeaderBar::notifyAlbumProperty()
     }
 }
 
+void ManageHeaderBar::notifyAlbumArtistProperty()
+{
+    auto newAlbumArtistValue = mCurrentTrack.data(mAlbumArtistRole);
+    if (mOldAlbumArtist != newAlbumArtistValue) {
+        Q_EMIT albumArtistChanged();
+
+        mOldAlbumArtist = newAlbumArtistValue;
+    }
+}
+
+void ManageHeaderBar::notifyFileNameProperty()
+{
+    auto newFileNameValue = mCurrentTrack.data(mFileNameRole);
+    if (mOldFileName != newFileNameValue) {
+        Q_EMIT fileNameChanged();
+
+        mOldFileName = newFileNameValue;
+    }
+}
+
 void ManageHeaderBar::notifyImageProperty()
 {
     auto newImageValue = mCurrentTrack.data(mImageRole);
@@ -313,6 +417,21 @@ void ManageHeaderBar::notifyImageProperty()
     }
 }
 
+void ManageHeaderBar::notifyDatabaseIdProperty()
+{
+    bool conversionOk;
+    auto newDatabaseIdValue = mCurrentTrack.data(mDatabaseIdRole).toULongLong(&conversionOk);
+    if (conversionOk && mOldDatabaseId != newDatabaseIdValue) {
+        Q_EMIT databaseIdChanged();
+
+        mOldDatabaseId = newDatabaseIdValue;
+    } else if (!conversionOk && mOldDatabaseId != 0) {
+        Q_EMIT databaseIdChanged();
+
+        mOldDatabaseId = 0;
+    }
+}
+
 void ManageHeaderBar::notifyAlbumIdProperty()
 {
     bool conversionOk;
@@ -373,7 +492,10 @@ void ManageHeaderBar::setCurrentTrack(const QPersistentModelIndex &currentTrack)
     notifyArtistProperty();
     notifyTitleProperty();
     notifyAlbumProperty();
+    notifyAlbumArtistProperty();
+    notifyFileNameProperty();
     notifyImageProperty();
+    notifyDatabaseIdProperty();
     notifyAlbumIdProperty();
     notifyIsValidProperty();
 }
