@@ -56,11 +56,26 @@ class ELISALIB_EXPORT ManageHeaderBar : public QObject
                WRITE setAlbumRole
                NOTIFY albumRoleChanged)
 
+    Q_PROPERTY(int albumArtistRole
+               READ albumArtistRole
+               WRITE setAlbumArtistRole
+               NOTIFY albumArtistRoleChanged)
+
+    Q_PROPERTY(int fileNameRole
+               READ fileNameRole
+               WRITE setFileNameRole
+               NOTIFY fileNameRoleChanged)
+
     Q_PROPERTY(int imageRole
                READ imageRole
                WRITE setImageRole
                NOTIFY imageRoleChanged)
 
+    Q_PROPERTY(int databaseIdRole
+               READ databaseIdRole
+               WRITE setDatabaseIdRole
+               NOTIFY databaseIdRoleChanged)
+
     Q_PROPERTY(int albumIdRole
                READ albumIdRole
                WRITE setAlbumIdRole
@@ -83,10 +98,22 @@ class ELISALIB_EXPORT ManageHeaderBar : public QObject
                READ album
                NOTIFY albumChanged)
 
+    Q_PROPERTY(QVariant albumArtist
+               READ albumArtist
+               NOTIFY albumArtistChanged)
+
+    Q_PROPERTY(QString fileName
+               READ fileName
+               NOTIFY fileNameChanged)
+
     Q_PROPERTY(QUrl image
                READ image
                NOTIFY imageChanged)
 
+    Q_PROPERTY(qulonglong databaseId
+               READ databaseId
+               NOTIFY databaseIdChanged)
+
     Q_PROPERTY(qulonglong albumId
                READ albumId
                NOTIFY albumIdChanged)
@@ -113,8 +140,14 @@ public:
 
     int albumRole() const;
 
+    int albumArtistRole() const;
+
+    int fileNameRole() const;
+
     int imageRole() const;
 
+    int databaseIdRole() const;
+
     int albumIdRole() const;
 
     int isValidRole() const;
@@ -125,8 +158,14 @@ public:
 
     QVariant album() const;
 
+    QVariant albumArtist() const;
+
+    QString fileName() const;
+
     QUrl image() const;
 
+    qulonglong databaseId() const;
+
     qulonglong albumId() const;
 
     bool isValid() const;
@@ -145,8 +184,14 @@ Q_SIGNALS:
 
     void albumRoleChanged();
 
+    void albumArtistRoleChanged();
+
+    void fileNameRoleChanged();
+
     void imageRoleChanged();
 
+    void databaseIdRoleChanged();
+
     void albumIdRoleChanged();
 
     void isValidRoleChanged();
@@ -157,10 +202,16 @@ Q_SIGNALS:
 
     void albumChanged();
 
+    void albumArtistChanged();
+
+    void fileNameChanged();
+
     void imageChanged();
 
     void remainingTracksChanged();
 
+    void databaseIdChanged();
+
     void albumIdChanged();
 
     void isValidChanged();
@@ -177,8 +228,14 @@ public Q_SLOTS:
 
     void setAlbumRole(int value);
 
+    void setAlbumArtistRole(int value);
+
+    void setFileNameRole(int value);
+
     void setImageRole(int value);
 
+    void setDatabaseIdRole(int databaseIdRole);
+
     void setAlbumIdRole(int albumIdRole);
 
     void setIsValidRole(int isValidRole);
@@ -203,8 +260,14 @@ private:
 
     void notifyAlbumProperty();
 
+    void notifyAlbumArtistProperty();
+
+    void notifyFileNameProperty();
+
     void notifyImageProperty();
 
+    void notifyDatabaseIdProperty();
+
     void notifyAlbumIdProperty();
 
     void notifyIsValidProperty();
@@ -221,8 +284,14 @@ private:
 
     int mAlbumRole = Qt::DisplayRole;
 
+    int mAlbumArtistRole = Qt::DisplayRole;
+
+    int mFileNameRole = Qt::DisplayRole;
+
     int mImageRole = Qt::DisplayRole;
 
+    int mDatabaseIdRole = Qt::DisplayRole;
+
     int mAlbumIdRole = Qt::DisplayRole;
 
     int mIsValidRole = Qt::DisplayRole;
@@ -233,8 +302,14 @@ private:
 
     QVariant mOldAlbum;
 
+    QVariant mOldAlbumArtist;
+
+    QVariant mOldFileName;
+
     QVariant mOldImage;
 
+    qulonglong mOldDatabaseId = 0;
+
     qulonglong mOldAlbumId = 0;
 
     bool mOldIsValid = false;
