@@ -71,6 +71,7 @@ QHash<int, QByteArray> FileBrowserModel::roleNames() const
     roles[static_cast<int>(ColumnsRoles::ContainerDataRole)] = "containerData";
     roles[static_cast<int>(ColumnsRoles::ImageUrlRole)] = "imageUrl";
     roles[static_cast<int>(ColumnsRoles::DirectoryRole)] = "directory";
+    roles[static_cast<int>(ColumnsRoles::IsPlayListRole)] = "isPlaylist";
 
     return roles;
 }
@@ -94,7 +95,7 @@ QVariant FileBrowserModel::data(const QModelIndex &index, int role) const
     case ColumnsRoles::ContainerDataRole:
     {
         KFileItem item = itemForIndex(index);
-        result = item.url();
+        result = item.url().toLocalFile();
         break;
     }
     case ColumnsRoles::ImageUrlRole:
@@ -108,10 +109,18 @@ QVariant FileBrowserModel::data(const QModelIndex &index, int role) const
         break;
     }
     case ColumnsRoles::DirectoryRole:
+    {
         KFileItem item = itemForIndex(index);
         result = item.isDir();
         break;
     }
+    case ColumnsRoles::IsPlayListRole:
+    {
+        KFileItem item = itemForIndex(index);
+        result = (item.currentMimeType().inherits(QStringLiteral("audio/x-mpegurl")));
+        break;
+    }
+    }
 
     return result;
 }
